@@ -6,8 +6,8 @@
 ;; Keywords: processes, tools
 ;; Homepage: https://github.com/purcell/envrc
 ;; Package-Requires: ((emacs "27.1") (inheritenv "0.1") (seq "2.24"))
-;; Package-Version: 20260209.1350
-;; Package-Revision: d3289e92e0e2
+;; Package-Version: 20260218.842
+;; Package-Revision: f44353c42c07
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -370,9 +370,9 @@ also appear in PAIRS."
   "Update BUF with RESULT, which is a result of `envrc--export'."
   (with-current-buffer buf
     (setq-local envrc--status (if (listp result) 'on result))
+    (envrc--clear buf)
     (if (memq result '(none error))
         (progn
-          (envrc--clear buf)
           (envrc--debug "[%s] reset environment to default" buf))
       (envrc--debug "[%s] applied merged environment" buf)
       (let* ((remote (when-let* ((fn (buffer-file-name buf)))
@@ -391,15 +391,15 @@ also appear in PAIRS."
         (if remote
             (setq-local envrc--remote-path parsed-path)
           (setq-local exec-path parsed-path))
-        (when (derived-mode-p 'eshell-mode)
-          (if (fboundp 'eshell-set-path)
-              (eshell-set-path path)
-            (setq-local eshell-path-env path)))
-        (when-let* ((info-path (getenv-internal "INFOPATH" env)))
-          (setq-local Info-directory-list
-                      (append (seq-filter #'identity (parse-colon-path info-path))
-                              (when (boundp 'Info-directory-list)
-                                (default-value 'Info-directory-list)))))))))
+        (cond ((derived-mode-p 'eshell-mode)
+               (if (fboundp 'eshell-set-path)
+                   (eshell-set-path path)
+                 (setq-local eshell-path-env path)))
+              ((derived-mode-p 'Info-mode)
+               (when-let* ((info-path (getenv-internal "INFOPATH" env)))
+                 (setq-local Info-directory-list
+                             (append (seq-filter #'identity (parse-colon-path info-path))
+                                     (default-value 'Info-directory-list))))))))))
 
 (defun envrc--update-env (env-dir)
   "Refresh the state of the direnv in ENV-DIR and apply in all relevant buffers."
